**_A most easily usable Geo Location API wrapper in Dart!_**

[![pub package](https://img.shields.io/pub/v/one_trust_geo_location.svg)](https://pub.dev/packages/one_trust_geo_location)
[![codecov](https://codecov.io/gh/myConsciousness/one-trust-geo-location/branch/main/graph/badge.svg?token=EDA7RU4F8N)](https://codecov.io/gh/myConsciousness/one-trust-geo-location)
[![Analyzer](https://github.com/myConsciousness/one-trust-geo-location/actions/workflows/analyzer.yml/badge.svg)](https://github.com/myConsciousness/one-trust-geo-location/actions/workflows/analyzer.yml)
[![Test](https://github.com/myConsciousness/one-trust-geo-location/actions/workflows/test.yml/badge.svg)](https://github.com/myConsciousness/one-trust-geo-location/actions/workflows/test.yml)

<!-- TOC -->

- [1. About](#1-about)
  - [1.1. Introduction](#11-introduction)
    - [1.1.1. What You Can Get](#111-what-you-can-get)
    - [1.1.2. Install Library](#112-install-library)
    - [1.1.3. Import It](#113-import-it)
    - [1.1.4. Use OneTrustGeoLocation](#114-use-onetrustgeolocation)
  - [1.2. License](#12-license)
  - [1.3. More Information](#13-more-information)

<!-- /TOC -->

# 1. About

`OneTrustGeoLocation` is an open-sourced Dart library.</br>
With `OneTrustGeoLocation`, you can easily and safely use `Geo Location API` made by [OneTrust](https://www.onetrust.com/) on your application.

**_This is an unofficial library._**

## 1.1. Introduction

### 1.1.1. What You Can Get

It is possible to get an approximate value for the current position. Note that the values such as zipcode and longitude/latitude are approximations and are not accurate.

For more details on the response data, refer to the [GeoLocationResponse](https://pub.dev/documentation/one_trust_geo_location/latest/one_trust_geo_location/GeoLocationResponse-class.html) class or the original [JSON data](https://github.com/myConsciousness/one-trust-geo-location/blob/main/design/response.json).

### 1.1.2. Install Library

**_With Dart:_**

```terminal
 dart pub add one_trust_geo_location
```

**_With Flutter:_**

```terminal
 flutter pub add one_trust_geo_location
```

### 1.1.3. Import It

```dart
import 'package:one_trust_geo_location/one_trust_geo_location.dart';
```

### 1.1.4. Use OneTrustGeoLocation

```dart
import 'package:one_trust_geo_location/one_trust_geo_location.dart' as location;

void main() async {
  // It's very easy to call api with get function.
  // It has no class so it's better to set alias 'location' like below.
  final response = await location.get();

  if (response.status.isNotOk) {
    // Do something when it's client or server error.
    if (response.status.isClientError) {
      return;
    } else if (response.status.isServerError) {
      return;
    } else {
      return;
    }
  }

  print(response.country);
  print(response.latitude);
  print(response.longitude);
}
```

## 1.2. License

```license
Copyright (c) 2021, Kato Shinya. All rights reserved.
Use of this source code is governed by a
BSD-style license that can be found in the LICENSE file.
```

## 1.3. More Information

`OneTrustGeoLocation` was designed and implemented by **_Kato Shinya_**.

- [Creator Profile](https://github.com/myConsciousness)
- [License](https://github.com/myConsciousness/one-trust-geo-location/blob/main/LICENSE)
- [API Document](https://pub.dev/documentation/one_trust_geo_location/latest/one_trust_geo_location/one_trust_geo_location-library.html)
- [Release Note](https://github.com/myConsciousness/one-trust-geo-location/releases)
- [Bug Report](https://github.com/myConsciousness/one-trust-geo-location/issues)
