// Copyright (c) 2021, Kato Shinya. All rights reserved.
// Use of this source code is governed by a
// BSD-style license that can be found in the LICENSE file.

// Package imports:
import 'package:http/http.dart';
import 'package:json_pro/json_pro.dart';

// Project imports:
import 'package:one_trust_geo_location/src/adapter/adapter.dart';
import 'package:one_trust_geo_location/src/response/geo_location_response.dart';

/// This class provides the function to convert the response
/// returned from the Geo Location API into the [GeoLocationResponse] format.
class GeoLocationApiAdapter extends Adapter<GeoLocationResponse> {
  /// Returns the new instance of [GeoLocationApiAdapter].
  GeoLocationApiAdapter.newInstance();

  @override
  GeoLocationResponse convert({
    required Response response,
  }) =>
      _buildGeoLocationResponse(
        response: response,
        json: Json.fromString(
          value: _scrapeJsonFeed(
            responseBody: response.body,
          ),
        ),
      );

  /// Returns [GeoLocationResponse] based on [response] and [json].
  GeoLocationResponse _buildGeoLocationResponse({
    required Response response,
    required Json json,
  }) =>
      GeoLocationResponse.from(
        statusCode: response.statusCode,
        reasonPhrase: response.reasonPhrase ?? '',
        headers: response.headers,
        country: json.getString(key: 'country'),
        state: json.getString(key: 'state'),
        stateName: json.getString(key: 'stateName'),
        zipcode: json.getString(key: 'zipcode'),
        timezone: json.getString(key: 'timezone'),
        latitude: json.getString(key: 'latitude'),
        longitude: json.getString(key: 'longitude'),
        city: json.getString(key: 'city'),
        continent: json.getString(key: 'continent'),
      );

  String _scrapeJsonFeed({
    required String responseBody,
  }) =>
      responseBody.substring(
        responseBody.indexOf('{'),
        responseBody.indexOf('}') + 1,
      );
}
