// Copyright (c) 2021, Kato Shinya. All rights reserved.
// Use of this source code is governed by a
// BSD-style license that can be found in the LICENSE file.

// Project imports:
import 'package:one_trust_geo_location/src/request/geo_location_request.dart';
import 'package:one_trust_geo_location/src/response/geo_location_response.dart';

/// Returns approximate information about the current location.
///
/// **_Example:_**
///
/// ```dart
/// void main() async {
///   // It's very easy to call api with get function.
///   // It has no class so it's better to set alias 'location' like below.
///   final response = await location.get();
///
///   if (response.status.isNotOk) {
///     // Do something when it's client or server error.
///     if (response.status.isClientError) {
///       return;
///     } else if (response.status.isServerError) {
///       return;
///     } else {
///       return;
///     }
///   }
///
///   print(response.country);
///   print(response.latitude);
///   print(response.longitude);
/// }
/// ```
Future<GeoLocationResponse> get() async =>
    GeoLocationRequest.newInstance().send();
