// Copyright (c) 2021, Kato Shinya. All rights reserved.
// Use of this source code is governed by a
// BSD-style license that can be found in the LICENSE file.

// Package imports:
import 'package:http/http.dart' as http;

// Project imports:
import 'package:one_trust_geo_location/src/adapter/geo_location_api_adapter.dart';
import 'package:one_trust_geo_location/src/request/request.dart';
import 'package:one_trust_geo_location/src/response/geo_location_response.dart';

/// This class represents a request to the Geo Location API.
class GeoLocationRequest extends Request<GeoLocationResponse> {
  /// Returns the new instance of [GeoLocationRequest].
  GeoLocationRequest.newInstance();

  /// The response adapter
  static final _adapter = GeoLocationApiAdapter.newInstance();

  /// The API uri
  static final _apiUri = Uri.parse(
    'https://geolocation.onetrust.com/cookieconsentpub/v1/geo/location',
  );

  @override
  Future<GeoLocationResponse> send() async => _adapter.convert(
        response: await http.post(_apiUri),
      );
}
