// Copyright (c) 2021, Kato Shinya. All rights reserved.
// Use of this source code is governed by a
// BSD-style license that can be found in the LICENSE file.

// Project imports:
import 'package:one_trust_geo_location/src/response/response.dart';

/// This is an abstract class that provides the functionality to send requests
/// to the Geo Location API. Then convert the response returned from the Geo Location API
/// into an entity object and returns it.
///
/// The response object returned from this abstract class always contains
/// the HTTP status code and header information in addition to the API-specific body data.
///
/// The generic of this abstract class should be the type
/// returned by the [send] method implemented in the concrete class
/// that inherits from this abstract class.
abstract class Request<R extends Response> {
  /// Sends a request to the Geo Location API.
  ///
  /// Also converts the response returned by the Geo Location API
  /// into an entity object corresponding to each Geo Location API
  /// and returns it.
  Future<R> send();
}
